from flask_shop import db
from werkzeug.security import generate_password_hash,check_password_hash
from datetime import datetime

#这两个时间不仅仅针对user表，也可能涉及到别的业务表，将其放在一个类中，作为公共的对待
#user想使用这两个时间，可以使用继承
class BaseModel:
    #记录注册账号的时间
    create_time = db.Column(db.DateTime,default=datetime.now)
    #修改密码的时间     onupdate=datetime.now为更新数据的时间
    update_time = db.Column(db.DateTime,default=datetime.now,onupdate=datetime.now)

#db里面已经连接好数据库，所以要继承db
class User(db.Model,BaseModel):
    __tablename__ = 't_user'
    id = db.Column(db.Integer,primary_key=True)
    name = db.Column(db.String(32),unique=True,nullable=False)
    pwd = db.Column(db.String(128))
    nick_name = db.Column(db.String(32))
    phone = db.Column(db.String(11))
    email = db.Column(db.String(32))

    # #记录注册账号的时间
    # create_time = db.Column(db.DateTime,default=datetime.now)
    # #修改密码的时间
    # update_time = db.Column(db.DateTime,default=datetime.now,onupdate=datetime.now)


    #存储密码，对外访问是通过password访问的,不是直接通过pwd访问的
    # u = User()
    # u.password
    # 赋值
    # u.password = '123'
    @property
    def password(self):
        return self.pwd

    #对返回的pwd做加密
    #过程：用户填写密码123，123是参数t_pwd,将123加密为hash格式返回给self.pwd
    #外面人通过password访问得到的是加密过得self.pwd
    @password.setter
    def password(self,t_pwd):
        self.pwd = generate_password_hash(t_pwd)

    #当用户登录时，给数据库传递的是pwd（是加密过的）
    #用户再次登录123时，与加密过的对应不上，所以要验证密码
    def check_password(self,t_pwd):
        #check_password_hash默认检测密码的方法
        #self.pwd代表跟谁去比较，第二个参数代表把t_pwd加密了去比较
        return check_password_hash(self.pwd,t_pwd)