'''
1、加密的数据   uid
2、算法         python模块
3、秘钥         flask_app   SECRET_KEY
'''

#引入序列化生成token
from itsdangerous import TimedJSONWebSignatureSerializer as Serializer
from flask import current_app,request
from flask_shop.models import User
from flask_shop.utils.message import to_dict_msg
import functools

#定义生成token的方法，两个参数：加密的数据、有效期
def generate_auth_token(uid,expiration):
    #创建加密对象，两个参数：秘钥、有效期
    s = Serializer(current_app.config['SECRET_KEY'],expires_in=expiration)
    #生成token,用字典的方式加密uid，decode是转换
    return s.dumps({'id':uid}).decode()

#客户再次登录，需要对token做验证,参数是用户传入的token
def verify_auth_token(token_str):
    #创建解密对象，不需要有效期
    s = Serializer(current_app.config['SECRET_KEY'])
    #产生数据,若有效期过期不能生成加密对象，所以加try，过期报None
    try:
        data = s.loads(token_str)
    except Exception:
        return None
    #通过解密的id来查找用户id
    usr = User.query.filter_by(id = data['id']).first()
    return usr

#登录必须请求的装饰器,传的是函数        相当于重写上面的方法
def login_required(view_func):
    #为了避免丢失参数，将引入高级函数
    functools.wraps(view_func)
    #定义自己处理的东西，需要接受相应的参数
    def verify_token(*arg,**kwargs):
        #获取数据,token是通过前端访问过来是通过请求头响应出来
        #有可能获取不到token，说明没登录
        try:
            token = request.headers['token']
        except Exception:
            return to_dict_msg(10006)
        #创建解密对象，不需要有效期    
        #每次重启，秘钥不同，所以验证不通过，重建立验证
        s = Serializer(current_app.config['SECRET_KEY'])
        #产生数据,若有效期过期不能生成加密对象，所以加try，过期报None
        try:
            data = s.loads(token)
        except Exception:
            return to_dict_msg(10007)
        #验证通过后,返回函数
        return view_func(*arg,**kwargs)
    #返回验证的信息
    return verify_token

         


